@@ -14,14 +14,14 @@
 -- @
 -- -- For a module that mostly uses esqueleto.
 -- import Database.Esqueleto
--- import qualified Database.Persistent as P
+-- import qualified Database.Persist as P
 -- @
 --
 -- or import @esqueleto@ itself qualified:
 --
 -- @
 -- -- For a module that uses esqueleto just on some queries.
--- import Database.Persistent
+-- import Database.Persist
 -- import qualified Database.Esqueleto as E
 -- @
 --
@@ -430,8 +430,9 @@ valJ = val . unValue
 
 -- | Synonym for 'Database.Persist.Store.delete' that does not
 -- clash with @esqueleto@'s 'delete'.
-deleteKey :: ( PersistStore (PersistEntityBackend val)
+deleteKey :: ( PersistStore backend
+             , BaseBackend backend ~ PersistEntityBackend val
              , MonadIO m
              , PersistEntity val )
-          => Key val -> ReaderT (PersistEntityBackend val) m ()
+          => Key val -> ReaderT backend m ()
 deleteKey = Database.Persist.delete
